/* Editor Settings: expandtabs and use 4 spaces for indentation
 * ex: set softtabstop=4 tabstop=8 expandtab shiftwidth=4: *
 * -*- mode: c, c-basic-offset: 4 -*- */

/*
 * Copyright (c) Likewise Software.  All rights Reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the license, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser
 * General Public License for more details.  You should have received a copy
 * of the GNU Lesser General Public License along with this program.  If
 * not, see <http://www.gnu.org/licenses/>.
 *
 * LIKEWISE SOFTWARE MAKES THIS SOFTWARE AVAILABLE UNDER OTHER LICENSING
 * TERMS AS WELL.  IF YOU HAVE ENTERED INTO A SEPARATE LICENSE AGREEMENT
 * WITH LIKEWISE SOFTWARE, THEN YOU MAY ELECT TO USE THE SOFTWARE UNDER THE
 * TERMS OF THAT SOFTWARE LICENSE AGREEMENT INSTEAD OF THE TERMS OF THE GNU
 * LESSER GENERAL PUBLIC LICENSE, NOTWITHSTANDING THE ABOVE NOTICE.  IF YOU
 * HAVE QUESTIONS, OR WISH TO REQUEST A COPY OF THE ALTERNATE LICENSING
 * TERMS OFFERED BY LIKEWISE SOFTWARE, PLEASE CONTACT LIKEWISE SOFTWARE AT
 * license@likewise.com
 */

#ifndef __SRV_ECP_H__
#define __SRV_ECP_H__

#define SRV_ECP_TYPE_SHARE_NAME     "Likewise.SRV.ShareName"
#define SRV_ECP_TYPE_CLIENT_ADDRESS "Likewise.SRV.ClientAddress"
#define SRV_ECP_TYPE_MAX_ACCESS     "Likewise.SRV.MaximalAccess"
#define SRV_ECP_TYPE_ABE            "Likewise.SRV.AccessBasedEnumeration"
#define SRV_ECP_TYPE_OEM_SESSION    "Likewise.SRV.OEMSession"
#define SRV_ECP_TYPE_NET_OPEN_INFO   "Likewise.SRV.NetworkOpenInfo"
#define SRV_ECP_TYPE_PIPE_INFO       "Likewise.SRV.FilePipeInfo"
#define SRV_ECP_TYPE_PIPE_LOCAL_INFO "Likewise.SRV.FilePipeLocalInfo"

#endif /* __SRV_ECP_H__ */
